@@ -47,22 +47,24 @@ namespace Kwave
 	BandPassPlugin(QObject *parent, const QVariantList &args);
 
 	/** Destructor */
-	virtual ~BandPassPlugin();
+        virtual ~BandPassPlugin() Q_DECL_OVERRIDE;
 
 	/** Creates the setup dialog and connects it's signals */
-	Kwave::PluginSetupDialog *createDialog(QWidget *parent) Q_DECL_OVERRIDE;
+        virtual Kwave::PluginSetupDialog *createDialog(QWidget *parent)
+            Q_DECL_OVERRIDE;
 
 	/**
 	 * Creates a multi-track filter with the given number of tracks
 	 * @param tracks number of tracks that the filter should have
 	 * @return pointer to the filter or null if failed
 	 */
-	Kwave::SampleSource *createFilter(unsigned int tracks) Q_DECL_OVERRIDE;
+        virtual Kwave::SampleSource *createFilter(unsigned int tracks)
+            Q_DECL_OVERRIDE;
 
 	/**
 	 * Returns true if the parameters have changed during pre-listen.
 	 */
-	bool paramsChanged() Q_DECL_OVERRIDE;
+        virtual bool paramsChanged() Q_DECL_OVERRIDE;
 
 	/**
 	 * Update the filter with new parameters if it has changed
@@ -71,19 +73,19 @@ namespace Kwave
 	 *               same one as created with createFilter()
 	 * @param force if true, even update if no settings have changed
 	 */
-	void updateFilter(Kwave::SampleSource *filter,
-	                  bool force = false) Q_DECL_OVERRIDE;
+        virtual void updateFilter(Kwave::SampleSource *filter,
+	                          bool force = false) Q_DECL_OVERRIDE;
 
 	/**
 	 * Returns a verbose name of the performed action. Used for giving
 	 * the undo action a readable name.
 	 */
-	QString actionName() Q_DECL_OVERRIDE;
+        virtual QString actionName() Q_DECL_OVERRIDE;
 
     protected:
 
 	/** Reads values from the parameter list */
-	int interpreteParameters(QStringList &params) Q_DECL_OVERRIDE;
+        virtual int interpreteParameters(QStringList &params) Q_DECL_OVERRIDE;
 
     protected slots:
 
