@@ -58,9 +58,9 @@ Kwave::OpusDecoder::OpusDecoder(QIODevice *source,
                                 ogg_page &og,
                                 ogg_packet &op)
     :m_source(source), m_stream_start_pos(0), m_samples_written(0),
-     m_oy(oy), m_os(os), m_og(og), m_op(op), m_opus_decoder(0),
-     m_comments_map(), m_raw_buffer(0), m_buffer(0),
-     m_rate_converter(0),
+     m_oy(oy), m_os(os), m_og(og), m_op(op), m_opus_decoder(Q_NULLPTR),
+     m_comments_map(), m_raw_buffer(Q_NULLPTR), m_buffer(Q_NULLPTR),
+     m_rate_converter(Q_NULLPTR),
      m_output_is_connected(false),
      m_packet_count(0), m_samples_raw(0), m_bytes_count(0),
      m_packet_len_min(0), m_packet_len_max(0),
@@ -632,11 +632,11 @@ void Kwave::OpusDecoder::reset()
 {
     if (m_opus_decoder)
 	opus_multistream_decoder_destroy(m_opus_decoder);
-    m_opus_decoder = 0;
+    m_opus_decoder = Q_NULLPTR;
 
     if (m_raw_buffer)
 	free(m_raw_buffer);
-    m_raw_buffer = 0;
+    m_raw_buffer = Q_NULLPTR;
 
 }
 
@@ -655,10 +655,10 @@ void Kwave::OpusDecoder::close(Kwave::FileInfo &info)
     }
 
     if (m_buffer) delete m_buffer;
-    m_buffer = 0;
+    m_buffer = Q_NULLPTR;
 
     delete m_rate_converter;
-    m_rate_converter = 0;
+    m_rate_converter = Q_NULLPTR;
 
     m_output_is_connected = false;
 
