@@ -66,7 +66,7 @@ QStringList *Kwave::SaveBlocksPlugin::setup(QStringList &previous_params)
     // create the setup dialog
     sample_index_t selection_left  = 0;
     sample_index_t selection_right = 0;
-    selection(0, &selection_left, &selection_right, false);
+    selection(Q_NULLPTR, &selection_left, &selection_right, false);
 
     // enable the "selection only" checkbox only if there is something
     // selected but not everything
@@ -91,7 +91,7 @@ QStringList *Kwave::SaveBlocksPlugin::setup(QStringList &previous_params)
 	    m_selection_only,
 	    enable_selection_only
 	);
-    if (!dialog) return 0;
+        if (!dialog) return Q_NULLPTR;
 
     // connect the signals/slots from the plugin and the dialog
     connect(dialog, SIGNAL(sigSelectionChanged(QString,
@@ -105,7 +105,7 @@ QStringList *Kwave::SaveBlocksPlugin::setup(QStringList &previous_params)
     dialog->emitUpdate();
     if (dialog->exec() != QDialog::Accepted) {
 	delete dialog;
-	return 0;
+        return Q_NULLPTR;
     }
 
     QStringList *list = new(std::nothrow) QStringList();
@@ -118,7 +118,7 @@ QStringList *Kwave::SaveBlocksPlugin::setup(QStringList &previous_params)
 	if (url.isEmpty()) {
 	    delete dialog;
 	    delete list;
-	    return 0;
+            return Q_NULLPTR;
 	}
 	QString name = url.path();
 	QFileInfo path(name);
@@ -199,7 +199,7 @@ int Kwave::SaveBlocksPlugin::start(QStringList &params)
     // determine the selection settings
     sample_index_t selection_left  = 0;
     sample_index_t selection_right = 0;
-    selection(0, &selection_left, &selection_right, false);
+    selection(Q_NULLPTR, &selection_left, &selection_right, false);
 
     bool selected_something = (selection_left != selection_right);
     bool selected_all = ( (selection_left == 0) &&
@@ -230,7 +230,7 @@ int Kwave::SaveBlocksPlugin::start(QStringList &params)
     Kwave::FileInfo file_info(orig_file_info);
     QList<Kwave::FileProperty> unsupported_properties;
     {
-	QString mimetype = Kwave::CodecManager::whatContains(m_url);
+	QString mimetype = Kwave::CodecManager::mimeTypeOf(m_url);
 	Kwave::Encoder *encoder = Kwave::CodecManager::encoder(mimetype);
 	if (encoder) {
 	    unsupported_properties = encoder->unsupportedProperties(
@@ -252,16 +252,16 @@ int Kwave::SaveBlocksPlugin::start(QStringList &params)
 	QUrl url = m_url.adjusted(QUrl::RemoveFilename);
 	url.setPath(url.path(QUrl::FullyEncoded) + name, QUrl::StrictMode);
 
-	QString filename = url.path();
-	QFileInfo file_info(filename);
+	QString p = url.path();
+	QFileInfo fi(p);
 
 	// check for potentially overwritten file
-	if (file_info.exists())
+	if (fi.exists())
 	    overwritten_files += Kwave::Parser::unescape(display_name);
 
 	// check for missing subdirectory
-	if (!file_info.dir().exists()) {
-	    QString missing_dir = file_info.absolutePath();
+	if (!fi.dir().exists()) {
+	    QString missing_dir = fi.absolutePath();
 	    if (!missing_dirs.contains(missing_dir))
 		missing_dirs += missing_dir;
 	}
@@ -306,17 +306,17 @@ int Kwave::SaveBlocksPlugin::start(QStringList &params)
 		QString::fromLatin1(QUrl::toPercentEncoding(missing)),
 		QUrl::StrictMode
 	    );
-	    QString path = url.path();
+	    QString p = url.path();
 	    QDir dir;
-	    if (!dir.mkpath(path))
-		qWarning("creating path '%s' failed", DBG(path));
+	    if (!dir.mkpath(p))
+		qWarning("creating path '%s' failed", DBG(p));
 	}
     }
 
     // save the current selection, we have to restore it afterwards!
     sample_index_t saved_selection_left  = 0;
     sample_index_t saved_selection_right = 0;
-    selection(0, &saved_selection_left, &saved_selection_right, false);
+    selection(Q_NULLPTR, &saved_selection_left, &saved_selection_right, false);
 
     // now we can loop over all blocks and save them
     sample_index_t block_start;
@@ -456,7 +456,7 @@ void Kwave::SaveBlocksPlugin::scanBlocksToSave(const QString &base,
     Kwave::Label label = (it.hasNext()) ? it.next() : Kwave::Label();
 
     if (selection_only) {
-	selection(0, &selection_left, &selection_right, true);
+        selection(Q_NULLPTR, &selection_left, &selection_right, true);
     } else {
 	selection_left  = 0;
 	selection_right = signalLength() - 1;
