@@ -48,7 +48,8 @@ Kwave::StringEnterPlugin::~StringEnterPlugin()
 void Kwave::StringEnterPlugin::load(QStringList &params)
 {
     Q_UNUSED(params);
-    QString entry = _("menu(plugin:setup(stringenter),%1/%2,F12)");
+    QString entry =
+	_("menu(plugin:setup(stringenter),%1/%2/#icon(editor),F12)");
     emitCommand(entry.arg(_("Settings")).arg(_(I18N_NOOP2(
         "menu: /Settings/Enter Command",
                         "Enter Command")
@@ -66,7 +67,7 @@ QStringList *Kwave::StringEnterPlugin::setup(QStringList &previous_params)
     QPointer<Kwave::StringEnterDialog> dialog =
 	new Kwave::StringEnterDialog(parentWidget(), preset);
     Q_ASSERT(dialog);
-    if (!dialog) return 0;
+    if (!dialog) return Q_NULLPTR;
 
     QStringList *list = new QStringList();
     Q_ASSERT(list);
@@ -77,7 +78,7 @@ QStringList *Kwave::StringEnterPlugin::setup(QStringList &previous_params)
     } else {
 	// user pressed "Cancel"
 	if (list) delete list;
-	list = 0;
+        list = Q_NULLPTR;
     }
 
     if (dialog) delete dialog;
